import datetime
import smtplib
from email.mime.text import MIMEText
from flask_sqlalchemy import SQLAlchemy
from flask import current_app

db = SQLAlchemy()

class Activity(db.Model):
    """Athletic activity"""
    __tablename__ = "activity"
    id = db.Column(db.Integer, primary_key=True)
    strava_id = db.Column(db.Integer, index=True)
    type = db.Column(db.Text, index=True)
    name = db.Column(db.String)
    description = db.Column(db.Text)
    moving_time = db.Column(db.Interval)
    distance = db.Column(db.Float)

class StravaApiToken(db.Model):
    """API token for Strava"""
    __tablename__ = "strava_api_token"
    id = db.Column(db.Integer, primary_key=True)
    token = db.Column(db.String)

class ContactFormSubmission(db.Model):
    """Submission via the contact form"""
    __tablename__ = "contact_form_submission"
    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.DateTime)
    name = db.Column(db.String)
    email = db.Column(db.String)
    text = db.Column(db.Text)


    def __init__(self, **kwargs):
        kwargs['date'] = datetime.datetime.now()
        super(ContactFormSubmission, self).__init__(**kwargs)
        footer = "\n\nSubmitted via website contact form."
        msg = MIMEText("{body}\n\n{footer}".format(body=self.text, footer=footer))
        msg['Subject'] = 'Website Contact Form Submission'
        msg['From'] = '{name} <{email}>'.format(name=self.name, email=self.email)
        msg['To'] = current_app.config.get('ADMIN_EMAIL')
        s = smtplib.SMTP(current_app.config.get('SMTP_HOST', 'localhost'))
        s.send_message(msg)
        s.quit()
